@@ -237,7 +237,7 @@ EVALUATE_OPS = ('undefined', 'add', 'and', 'divide', 'leftshift', 'max',
                 'uniformnoise', 'cosine', 'sine', 'addmodulus', 'mean',
                 'abs', 'exponential', 'median', 'sum')
 
-#: (:class:`tuple`) The list of alpha chanell types
+#: (:class:`tuple`) The list of alpha channel types
 #:
 #: - ``'undefined'``
 #: - ``'activate'``
@@ -616,7 +616,7 @@ class Image(Resource):
 
     @units.setter
     def units(self, units):
-        if not isinstance(units, basestring) or units not in UNIT_TYPES: 
+        if not isinstance(units, basestring) or units not in UNIT_TYPES:
             raise TypeError('Unit value must be a string from wand.images.'
                             'UNIT_TYPES, not ' + repr(units))
         r = library.MagickSetImageUnits(self.wand, UNIT_TYPES.index(units))
@@ -671,9 +671,13 @@ class Image(Resource):
         if not isinstance(fmt, basestring):
             raise TypeError("format must be a string like 'png' or 'jpeg'"
                             ', not ' + repr(fmt))
-        r = library.MagickSetImageFormat(self.wand, fmt.strip().upper())
+        fmt = fmt.strip()
+        r = library.MagickSetImageFormat(self.wand, fmt.upper())
         if not r:
             raise ValueError(repr(fmt) + ' is unsupported format')
+        r = library.MagickSetFilename(self.wand, 'buffer.' + fmt.lower())
+        if not r:
+            self.raise_exception()
 
     @property
     def type(self):
@@ -1091,6 +1095,12 @@ class Image(Resource):
         :param resize: A geometry string defining the final size of the image
         :type resize: :class:`basestring`
 
+        .. note::
+
+           :issue:`104`  reported that :meth:`transform()` leaks memory
+           under version 0.3.0, so be careful when you use it on long-running
+           process like web server.
+
         .. seealso::
 
            `ImageMagick Geometry Specifications`__
@@ -1189,7 +1199,7 @@ class Image(Resource):
                                        IMAGE_TYPES.index('truecolormatte'))
             # Perform the black channel subtraction
             library.MagickEvaluateImageChannel(self.wand,
-                                               CHANNELS['black'],
+                                               CHANNELS['opacity'],
                                                EVALUATE_OPS.index('subtract'),
                                                t)
             self.raise_exception()
