@@ -5,12 +5,13 @@ There is the global resource to manage in MagickWand API. This module
 implements automatic global resource management through reference counting.
 
 """
-import logging
 import contextlib
 import ctypes
+import logging
 import warnings
-from . import exceptions
+
 from .api import library
+from . import exceptions
 
 
 __all__ = ('genesis', 'terminus', 'increment_refcount', 'decrement_refcount',
@@ -103,6 +104,8 @@ class Resource(object):
                 with self.allocate():
                     self.resource = library.NewPizza()
 
+    .. versionadded:: 0.1.2
+
     """
 
     #: (:class:`ctypes.CFUNCTYPE`) The :mod:`ctypes` predicate function
@@ -157,7 +160,7 @@ class Resource(object):
         if self.c_is_resource(resource):
             self.c_resource = resource
         else:
-            raise TypeError(repr(wand) + ' is an invalid resource')
+            raise TypeError(repr(resource) + ' is an invalid resource')
         increment_refcount()
 
     @resource.deleter
